Gemini.Auth.GeminiStrategy (GeminiEx v0.8.8)
View SourceAuthentication strategy for Google Gemini API using API key.
This strategy uses the simple x-goog-api-key header authentication method used by the Gemini API.
Authentication strategy for Google Gemini API using API key.
This strategy uses the simple x-goog-api-key header authentication method used by the Gemini API.