Gemini.Types.Live.GoAway (GeminiEx v0.11.0)

Copy Markdown View Source

Notice from the server that the connection will soon be terminated.

When received, clients should prepare to disconnect and optionally use session resumption to continue the session on a new connection.

Fields

  • time_left - Duration string indicating remaining time before termination

Example

%GoAway{time_left: "30s"}

Summary

Functions

Parses from API response.

Creates a new GoAway message.

Converts to API format (camelCase).

Types

t()

@type t() :: %Gemini.Types.Live.GoAway{time_left: String.t() | nil}

Functions

from_api(data)

@spec from_api(map() | nil) :: t() | nil

Parses from API response.

new(opts \\ [])

@spec new(keyword()) :: t()

Creates a new GoAway message.

to_api(value)

@spec to_api(t() | nil) :: map() | nil

Converts to API format (camelCase).