Gemini.Types.Live.SetupComplete (GeminiEx v0.11.0)

Copy Markdown View Source

Setup complete message from the server.

Sent in response to a Setup message from the client when the session is successfully configured and ready for use.

Fields

  • session_id - The session ID of the live session

Example

%SetupComplete{session_id: "session_abc123"}

Summary

Functions

Parses from API response.

Creates a new SetupComplete.

Converts to API format (camelCase).

Types

t()

@type t() :: %Gemini.Types.Live.SetupComplete{session_id: String.t() | nil}

Functions

from_api(data)

@spec from_api(map() | nil) :: t() | nil

Parses from API response.

new(opts \\ [])

@spec new(keyword()) :: t()

Creates a new SetupComplete.

to_api(value)

@spec to_api(t() | nil) :: map() | nil

Converts to API format (camelCase).