Gemini.Types.Live.ToolCallCancellation (GeminiEx v0.11.0)

Copy Markdown View Source

Tool call cancellation notification from the server.

Notification that previously issued tool calls with the specified IDs should be cancelled. This occurs when clients interrupt server turns.

If there were side-effects to those tool calls, clients may attempt to undo them.

Fields

  • ids - List of tool call IDs to be cancelled

Example

%ToolCallCancellation{ids: ["call_123", "call_456"]}

Summary

Functions

Parses from API response.

Creates a new ToolCallCancellation.

Converts to API format (camelCase).

Types

t()

@type t() :: %Gemini.Types.Live.ToolCallCancellation{ids: [String.t()] | nil}

Functions

from_api(data)

@spec from_api(map() | nil) :: t() | nil

Parses from API response.

new(opts \\ [])

@spec new(keyword()) :: t()

Creates a new ToolCallCancellation.

to_api(value)

@spec to_api(t() | nil) :: map() | nil

Converts to API format (camelCase).