Configuration for multi-speaker voice synthesis.
Allows assigning different voices to different speakers in the output.
Summary
Types
@type t() :: %Gemini.Types.MultiSpeakerVoiceConfig{ speaker_voice_configs: [Gemini.Types.SpeakerVoiceConfig.t()] }
Configuration for multi-speaker voice synthesis.
Allows assigning different voices to different speakers in the output.
@type t() :: %Gemini.Types.MultiSpeakerVoiceConfig{ speaker_voice_configs: [Gemini.Types.SpeakerVoiceConfig.t()] }