Session resumption state update from the server.
Only sent if session_resumption was set in the connection config.
Contains information about whether the session can be resumed and the
handle to use for resumption.
Fields
new_handle- New handle representing a state that can be resumed. Empty if not resumable.resumable- True if the session can be resumed at this point.last_consumed_client_message_index- Index of last message processed (only with transparent mode).
Example
%SessionResumptionUpdate{
new_handle: "session_handle_123",
resumable: true,
last_consumed_client_message_index: 42
}
Summary
Functions
Parses from API response.
Creates a new SessionResumptionUpdate.
Converts to API format (camelCase).