Setup complete message from the server.
Sent in response to a Setup message from the client when the session is successfully configured and ready for use.
Fields
session_id- The session ID of the live session
Example
%SetupComplete{session_id: "session_abc123"}
Summary
Functions
Parses from API response.
Creates a new SetupComplete.
Converts to API format (camelCase).
Types
@type t() :: %Gemini.Types.Live.SetupComplete{session_id: String.t() | nil}