Tool call cancellation notification from the server.
Notification that previously issued tool calls with the specified IDs should be cancelled. This occurs when clients interrupt server turns.
If there were side-effects to those tool calls, clients may attempt to undo them.
Fields
ids- List of tool call IDs to be cancelled
Example
%ToolCallCancellation{ids: ["call_123", "call_456"]}
Summary
Functions
Parses from API response.
Creates a new ToolCallCancellation.
Converts to API format (camelCase).
Types
@type t() :: %Gemini.Types.Live.ToolCallCancellation{ids: [String.t()] | nil}