Utilities for normalizing Google Cloud resource names for Gemini/Vertex AI.
Summary
Functions
Build the base cachedContents collection path for the active auth strategy.
Normalize a cache model name for the active auth strategy.
Normalize cached content names for the active auth strategy.
Functions
Build the base cachedContents collection path for the active auth strategy.
Normalize a cache model name for the active auth strategy.
- Gemini: ensures
models/prefix. - Vertex: expands to
projects/{project}/locations/{location}/publishers/google/models/{model}.
Normalize cached content names for the active auth strategy.
- Gemini: ensures
cachedContents/prefix. - Vertex: expands short names to
projects/{project}/locations/{location}/cachedContents/{id}.